import src.modules.RTD8.service as service
from fastapi import APIRouter
from typing import Dict



router = APIRouter(prefix="/RTD8", tags=["Modules --> RTD8 card"])



@router.get("/all", summary="Read all RTD8 cards values in Celsius", response_model=Dict[int, Dict[int, float]])
def get_all_celsius():
    return service.read_temp_all()

@router.get("/{stack}", summary="Read specified RTD8 card values in Celsius", response_model=Dict[int, float])
def get_stack_celsius(stack: int):
    return service.read_temp_stack(stack)

@router.get("/{stack}/{channel}", summary="Read specified RTD8 card value of specified channel in Celsius", response_model=float)
def get_channel_celsius(stack: int, channel: int):
    return service.read_temp(stack, channel)



@router.get("/all/resistance", summary="Read all RTD8 cards values in Ohm", response_model=Dict[int, Dict[int, float]])
def get_all_celsius():
    return service.read_resistance_all()

@router.get("/{stack}/resistance", summary="Read specified RTD8 card values in Ohm", response_model=Dict[int, float])
def get_stack_celsius(stack: int):
    return service.read_resistance_stack(stack)

@router.get("/{stack}/{channel}/resistance", summary="Read specified RTD8 card value of specified channel in Ohm", response_model=float)
def get_channel_celsius(stack: int, channel: int):
    return service.read_resistance(stack, channel)